@@ -9,7 +9,7 @@ use strict;
 use warnings;
 use base qw( Device::BusPirate::Chip );
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Carp;
 
@@ -118,30 +118,26 @@ sub mount
 Powers up the device, reads and checks the signature, ensuring it is a
 recognised chip.
 
+This method leaves the chip powered up with +5V on Vcc and +12V on RESET. Use
+the C<power>, C<hv_power> or C<all_power> methods to turn these off if it is
+not required again immediately.
+
 =cut
 
-my %PARTS = (
-   #                     Sig       Flash sz  Eeprom sz  EF
-   ATtiny24 => PartInfo( "1E910B", 1024, 16,   128, 4,  1 ),
-   ATtiny44 => PartInfo( "1E9207", 2048, 16,   256, 4,  1 ),
-   ATtiny84 => PartInfo( "1E930C", 4096, 32,   512, 4,  1 ),
-
-   ATtiny13 => PartInfo( "1E9007",  512, 16,    64, 4,  0 ),
-   ATtiny25 => PartInfo( "1E9108", 1024, 16,   128, 4,  1 ),
-   ATtiny45 => PartInfo( "1E9206", 2048, 32,   256, 4,  1 ),
-   ATtiny85 => PartInfo( "1E930B", 4096, 32,   512, 4,  1 ),
-);
+my %PARTS;
+{
+   local $_;
+   while( <DATA> ) {
+      my ( $name, $data ) = m/^(\S+)\s*=\s*(.*?)\s*$/ or next;
+      $PARTS{$name} = PartInfo( split /\s+/, $data );
+   }
+}
 
 sub start
 {
    my $self = shift;
 
-   # Allow power to settle before turning on +12V on AUX
-   # Normal serial line overheads should allow enough time here
-
-   $self->power(1)->then( sub {
-      $self->aux(1)
-   })->then( sub {
+   $self->all_power(1)->then( sub {
       $self->read_signature;
    })->then( sub {
       my ( $sig ) = @_;
@@ -192,6 +188,43 @@ sub stop
    );
 }
 
+=head2 $chip->power( $on )->get
+
+Controls +5V to the Vcc pin of the F<ATtiny> chip.
+
+=cut
+
+# inherited
+
+=head2 $chip->hv_power( $on )->get
+
+Controls +12V to the RESET pin of the F<ATtiny> chip.
+
+=cut
+
+*hv_power = __PACKAGE__->can( 'aux' );
+
+=head2 $chip->all_power( $on )->get
+
+Controls both +5V and +12V supplies at once. The +12V supply is turned on last
+but off first, ensuring the correct HVSP-RESET sequence is applied to the
+chip.
+
+=cut
+
+sub all_power
+{
+   my $self = shift;
+   my ( $on ) = @_;
+
+   # Allow power to settle before turning on +12V on AUX
+   # Normal serial line overheads should allow enough time here
+
+   $on
+      ? $self->power(1)->then( sub { $self->hv_power(1) } )
+      : $self->hv_power(0)->then( sub { $self->power(0) } );
+}
+
 =head2 $name = $chip->partname
 
 Returns the name of the chip whose signature was detected by the C<start>
@@ -265,6 +298,21 @@ sub memory_infos
    return @{ $self->{memories} };
 }
 
+=head2 $fuseinfo = $avr->fuseinfo
+
+Returns a L<Device::BusPirate::Chip::AVR_HVSP::FuseInfo> instance containing
+information on the fuses in the attached device type.
+
+=cut
+
+sub fuseinfo
+{
+   my $self = shift;
+
+   require Device::BusPirate::Chip::AVR_HVSP::FuseInfo;
+   return Device::BusPirate::Chip::AVR_HVSP::FuseInfo->for_part( $self->partname );
+}
+
 sub _transfer
 {
    my $self = shift;
@@ -509,7 +557,7 @@ sub write_fuse_byte
 
    my $sii = $SII_FOR_FUSE_WRITE{$fuse} or croak "Unrecognised fuse type '$fuse'";
 
-   $fuse eq "efuse" and !$self->{part}->has_efuse and
+   $fuse eq "efuse" and !$self->{partinfo}->has_efuse and
       croak "This part does not have an 'efuse'";
 
    $self->_transfer( CMD_WFUSE, HVSP_CMD )
@@ -801,3 +849,23 @@ Paul Evans <leonerd@leonerd.org.uk>
 =cut
 
 0x55AA;
+
+__DATA__
+# name       = Sig    Flash sz EEPROM sz efuse
+ATA5702M322  = 1E9569 32768 16   2304 16 0
+ATA5782      = 1E9565 16384 32   1152 16 0
+ATA5831      = 1E9561 16384 32   1152 16 0
+ATA5832      = 1E9562 16384 32   1152 16 0
+ATA5833      = 1E9563 16384 32   1152 16 0
+ATmega16HVA  = 1E940C  8192 64    256  4 0
+ATmega64HVE2 = 1E9610 32768 64   1024  4 0
+ATmega8HVA   = 1E9310  4096 64    256  4 0
+ATtiny13     = 1E9007   512 16     64  4 0
+ATtiny24     = 1E910B  1024 16    128  4 1
+ATtiny25     = 1E9108  1024 16    128  4 1
+ATtiny44     = 1E9207  2048 32    256  4 1
+ATtiny441    = 1E9215  2048  8    256  4 1
+ATtiny45     = 1E9206  2048 32    256  4 1
+ATtiny84     = 1E930C  4096 32    512  4 1
+ATtiny841    = 1E9315  4096  8    512  4 1
+ATtiny85     = 1E930B  4096 32    512  4 1
